yakumo.nova.v2.hypervisor.Manager

Package yakumo :: Package nova :: Package v2 :: Module hypervisor :: Class Manager |
[hide private]
[frames] | no frames]

# Class Manager

source code

      object --+
               |
    base.Manager --+
                   |
                  Manager

Manager class for hypervisors in Compute API v2

Nested Classes | [hide private]
| resource_class Resource class for hypervisors in Compute API v2

Instance Methods | [hide private]
dict |
get_total_stats(self) Aquire total statistics of hypervisors | source code
dict |
servers(self, host) Aquire hypervisor hosts | source code
Inherited from `base.Manager`: `__init__`, `create`, `find`, `find_one`, `get`, `get_empty`, `list` Inherited from `base.Manager` (private): `_attr2json`, `_find_gen`, `_json2attr`, `_no_such_api` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Class Variables | [hide private]
| service_type = ``'``compute``'``
| _attr_mapping = ``[``(``'``id``'``,` `'``id``'``,` <yakumo.mapper.NoopClass object `...``
| _hidden_methods = ``[``'``create``'``,` `'``update``'``]``
| _json_resource_key = ``'``hypervisor``'``
| _json_resources_key = ``'``hypervisors``'``
| _url_resource_path = ``'``/os-hypervisors``'``
Inherited from `base.Manager` (private): `_has_detail`, `_has_extra_attr`, `_id_attr`, `_update_method`, `_url_resource_list_path`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### get_total_stats(self) | source code
Aquire total statistics of hypervisors Returns: dict Statistics

### servers(self, host) | source code
Aquire hypervisor hosts Returns: dict Host list

Class Variable Details | [hide private]

  ### _attr_mapping Value:
      [('id', 'id', mapper.Noop), ('hostname', 'hypervisor_hostname', mapper
      .Noop), ('type', 'hypervisor_type', mapper.Noop), ('version', 'hypervi
      sor_version', mapper.Noop), ('cpu_info', 'cpu_info', mapper.Noop), ('w
      orkload', 'current_workload', mapper.Noop), ('disk_available_least', '
      disk_available_least', mapper.Noop), ('free_disk_gb', 'free_disk_gb',
      mapper.Noop), ('free_ram_mb', 'free_ram_mb', mapper.Noop), ('local_gb'
      , 'local_gb', mapper.Noop), ('local_gb_used', 'local_gb_used', mapper.
      Noop), ('memory_mb', 'memory_mb', mapper.Noop), ('memory_mb_used', 'me
      ...